SPIHTTPConsumer class

Inheritance
Implemented types

Constructors

SPIHTTPConsumer()

Properties

hashCode int
The hash code for this object.
no setterinherited
hc → Client
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
Closer is release hook
inherited
consume(Context ctx, String urn, Execution exec, Uint8List inbound) Future<Uint8List>
Consume the input payload. urn Actual uniform resource Domain Name. execution Service reference. inbound Input arguments. Output payload
inherited
consumes(Context ctx, String urn, Execution exec, Uint8List inbound) Stream<Uint8List>
Consumes sends the request and returns a stream of raw response bytes. The stream is closed when the server finishes streaming. urn Actual uniform resource Domain Name. execution Service reference. inbound Input arguments. Output stream of payload chunks
inherited
ioc() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() Future<void>
Start the mesh broker.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited