Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
close ()
→ Future <void >
Closer is release hook
consume (Context ctx , String urn , Execution exec , Uint8List inbound )
→ Future <Uint8List >
Consume the input payload.
urn Actual uniform resource Domain Name.
execution Service reference.
inbound Input arguments.
Output payload
consumes (Context ctx , String urn , Execution exec , Uint8List inbound )
→ Stream <Uint8List >
Consumes sends the request and returns a stream of raw response bytes.
The stream is closed when the server finishes streaming.
urn Actual uniform resource Domain Name.
execution Service reference.
inbound Input arguments.
Output stream of payload chunks
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start ()
→ Future <void >
Start the mesh broker.
toString ()
→ String
A string representation of this object.
inherited