consumes abstract method

Stream<Uint8List> consumes(
  1. Context ctx,
  2. String urn,
  3. Execution exec,
  4. Uint8List inbound,
)

Consumes sends the request and returns a stream of raw response bytes. The stream is closed when the server finishes streaming. urn Actual uniform resource Domain Name. execution Service reference. inbound Input arguments. Output stream of payload chunks

Implementation

Stream<Uint8List> consumes(
    Context ctx, String urn, Execution exec, Uint8List inbound);