Eden class abstract

Implementers
Annotations
  • @SPI(name: 'mesh')

Constructors

Eden()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

define(MPI mpi, dynamic ref, Context? ctx) → void
Define the reference object.
infer(String urn, Context? ctx) Execution?
Infer the reference service by Domain.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refer(MPI mpi, dynamic ref, Introspector method, Context? ctx) Execution?
Refer the service reference by method.
store(dynamic kind, dynamic service, Context? ctx) → void
Store the service object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited