MeshEden class

Implemented types
Implementers
Annotations
  • @SPI(name: 'mesh')

Constructors

MeshEden()

Properties

hashCode int
The hash code for this object.
no setterinherited
references Map<Introspector, Execution>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
services Map<String, Execution>
final

Methods

define(MPI mpi, dynamic ref, Context? ctx) → void
Define the reference object.
override
infer(String urn, Context? ctx) Execution?
Infer the reference service by Domain.
override
makeFlag(URC urc) URNFlag
makeURN(String alias, URNFlag flag, Environ env) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refer(MPI mpi, dynamic ref, Introspector method, Context? ctx) Execution?
Refer the service reference by method.
override
refMethod(Environ env, MPI rm, String name, Introspector method) Reference
store(dynamic kind, dynamic service, Context? ctx) → void
Store the service object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited