Hodor class abstract

Constructors

Hodor()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(Map<String, String> features, {Context? ctx}) Future<void>
Debug set the debug features.
dump({Context? ctx}) Future<String?>
Dump the application data.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stats(List<String> features, {Context? ctx}) Future<Map<String, String>?>
Stats collect the system, application, process or thread status etc.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited