Cache class abstract

Implementers
Annotations
  • @SPI(name: "mpi")

Constructors

Cache()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decr(String key, int value, {Context? ctx}) Future<int?>
Decr the cache of expire time. 缓存计数器减少计数.
get(String key, {Context? ctx}) Future<CacheBody?>
Get the value from cache. 从缓存中取数据.
hdel(String key, String name, {Context? ctx}) Future<void>
HDel del value in hashtable. 从缓存哈希表中删除值.
hget(String key, String name, {Context? ctx}) Future<CacheBody?>
HGet get value in hashtable. 从缓存哈希表中取值.
hkeys(String key, {Context? ctx}) Future<List<String>?>
HKeys get the hash keys. 从缓存哈希表中获取KEY集合.
hset(String key, CacheBody cell, {Context? ctx}) Future<void>
HSet put value in hashtable. 从缓存哈希表中写值.
incr(String key, int value, {Context? ctx}) Future<int?>
Incr the cache of expire time. 缓存计数器增加计数.
keys(String pattern, {Context? ctx}) Future<List<String>?>
Keys return the cache key set. 获取缓存中的KEY集合.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(CacheBody cell, {Context? ctx}) Future<void>
Put the value to cache. 写入数据到缓存.
remove(String key, {Context? ctx}) Future<void>
Remove the cache value. 从缓存删除数据.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited