CipherEconomy class abstract

Implementers
Annotations
  • @SPI(name: "mpi")

Constructors

CipherEconomy()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

collect(CipherObject obj, {Context? ctx}) Future<int?>
Collect cipher objects with group. Asyncable can be invoked by multi times. 中心化归集多方密钥加密的密态数据包(胶囊)用于中心化密态计算(重加密/重匿名/全同态等)
deposit(CipherObject rco, {Context? ctx}) Future<String?>
Deposit cipher object deposit. 密态数据包(胶囊)归档到密态数据胶囊中心仓库.
handshake(CipherHello hello, {Context? ctx}) Future<String?>
Handshake negotiate multiparty cipher keys. 多方密钥协商握手.
invoke(Script script, {Context? ctx}) Future<Uint8List?>
Invoke the script in cipher objects. 在密态数据包上执行计算脚本,SQL等.
keys(Paging idx, {Context? ctx}) Future<Page<Keys>?>
Keys key index. 分页检索仓库中的密态数据胶囊ID,即Manifest列表检索.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
objects(Paging idx, {Context? ctx}) Future<Page<CipherObject>?>
Objects cipher object index. 分页检索仓库中的密态数据胶囊.
serve(String suite, {Context? ctx}) Future<String?>
Serve will Encrypt or Anonymize. 提供加密或匿名服务托管能力,会把对应的密态服务发布为一个服务接口.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited