Cryptor class abstract

Implementers
Annotations
  • @SPI(name: "mpi")

Constructors

Cryptor()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decrypt(Uint8List buf, Map<String, Uint8List> keys, {Context? ctx}) Future<Uint8List?>
Decrypt binary to decrypted binary. 解密二进制数据.
encrypt(Uint8List buf, Map<String, Uint8List> keys, {Context? ctx}) Future<Uint8List?>
Encrypt binary to encrypted binary. 加密二进制数据.
hash(Uint8List buf, Map<String, Uint8List> keys, {Context? ctx}) Future<Uint8List?>
Hash compute the hash value. 对二进制数据计算摘要.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(Uint8List buf, Map<String, Uint8List> keys, {Context? ctx}) Future<Uint8List?>
Sign compute the signature value. 对二进制数据计算签名.
toString() String
A string representation of this object.
inherited
verify(Uint8List buf, Map<String, Uint8List> keys, {Context? ctx}) Future<bool?>
Verify the signature value. 对二进制数据摘要验签.

Operators

operator ==(Object other) bool
The equality operator.
inherited