Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
importReplica(Uint8List raw, {Context? ctx})
→ Future<String?>
-
ImportReplica import system data backup.
导入系统备份.
-
indexReplica(Paging idx, {Context? ctx})
→ Future<Page<Replica>?>
-
IndexReplica index system data backups.
分页检索系统备份数据.
-
init(String flags, {Context? ctx})
→ Future<void>
-
Init the system data.
初始化系统数据.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
readReplica(String code, {Context? ctx})
→ Future<Uint8List?>
-
ReadReplica read system data backup.
读取系统备份.
-
recover(String id, {Context? ctx})
→ Future<void>
-
Recover recover backup.
备份数据恢复.
-
removeReplica(String code, {Context? ctx})
→ Future<void>
-
RemoveReplica remove system data backup.
删除系统备份.
-
replicate(String appset, {Context? ctx})
→ Future<String?>
-
Replicate make a system data backup.
按应用备份系统数据.
-
setting(String appset, Settings setting, {Context? ctx})
→ Future<void>
-
Setting write the system settings.
覆盖系统设置信息,按appset进行覆盖.
-
settings({Context? ctx})
→ Future<Map<String, Settings>?>
-
Settings get the system settings.
获取系统设置信息,这是一个通用接口,可以设置所有的应用设置信息.
-
toString()
→ String
-
A string representation of this object.
inherited