Endpoint class abstract

Implementers
Annotations
  • @SPI(name: "mpi")

Constructors

Endpoint()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fuzzy(Uint8List buff, {Context? ctx}) Future<Uint8List?>
Fuzzy call with generic param In multi returns, it's an array.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited