fuzzy method
Fuzzy call with generic param In multi returns, it's an array.
Implementation
@MPI(name: "_{mesh.uname}")
Future<Uint8List?> fuzzy(Uint8List buff, {Context? ctx}) {
throw UnimplementedError('fuzzy() has not been implemented.');
}
Fuzzy call with generic param In multi returns, it's an array.
@MPI(name: "_{mesh.uname}")
Future<Uint8List?> fuzzy(Uint8List buff, {Context? ctx}) {
throw UnimplementedError('fuzzy() has not been implemented.');
}