Firewalld class abstract

Implementers
Annotations
  • @SPI(name: "mpi")

Constructors

Firewalld()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

describe(String code, {Context? ctx}) Future<Firewall?>
Describe the firewalld rule. 查看防火墙规则.
index(Paging idx, {Context? ctx}) Future<Page<Firewall>?>
Index the firewalld rules. 分页查看防火墙规则.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String code, {Context? ctx}) Future<void>
Remove the firewalld rule. 删除防火墙规则.
save(Firewall wall, {Context? ctx}) Future<String?>
Save the firewalld rules. 保存防火墙规则,支持保存包括黑白名单、限流熔断等逻辑.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited