KV class abstract

Implementers
Annotations
  • @SPI(name: "mpi")

Constructors

KV()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String key, {Context? ctx}) Future<Body?>
Get the value from kv store. 从KV存储读值.
index(Paging idx, {Context? ctx}) Future<Page<Entry>?>
Index the kv for webui 分页检索KV存储内容.
keys(String pattern, {Context? ctx}) Future<List<String>?>
Keys with the pattern of kv store. 检索KV存储中的所有KEY.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String key, Body value, {Context? ctx}) Future<void>
Put the value to kv store. 从KV写入值.
remove(String key, {Context? ctx}) Future<void>
Remove the kv store. 从KV删除值.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited