Licenser class abstract

Implementers
Annotations
  • @SPI(name: "mpi")

Constructors

Licenser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

explain({Context? ctx}) Future<License?>
Explain the license. 解释许可证书.
exports({Context? ctx}) Future<String?>
Exports the licenses. 导出许可证书.
features({Context? ctx}) Future<Map<String, String>?>
Features is license features. 查询系统提供的证书签发因子.
imports(String license, {Context? ctx}) Future<void>
Imports the licenses. 导入许可证书.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verify({Context? ctx}) Future<int?>
Verify the license. 验证许可证书.

Operators

operator ==(Object other) bool
The equality operator.
inherited