Network class abstract

Implementers
Annotations
  • @SPI(name: "mpi")

Constructors

Network()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accessible(Route route, {Context? ctx}) Future<bool?>
Accessible Check the mesh network is accessible. 组网信息网络可达性检测.
disable(String mdc, {Context? ctx}) Future<void>
Disable the network. 禁用当前节点到目标节点的所有网络通信.
enable(String mdc, {Context? ctx}) Future<void>
Enable the network 启用当前节点到目标节点的所有网络通信.
environ({Context? ctx}) Future<Environ?>
Environ Get the meth network environment fixed information. 获取MESH网络中的当前节点环境信息.
exports(String mdc, {Context? ctx}) Future<String?>
Exports the weave certificate. 导出当前节点到目标节点网络的证书信息.
imports(String mdc, String crt, {Context? ctx}) Future<void>
Imports the weave certificate. 导入当前节点到目标节点网络的证书信息.
index(Paging index, {Context? ctx}) Future<Page<Route>?>
Index the network routes. 分页检索组网列表.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refresh(List<Route> routes, {Context? ctx}) Future<void>
Refresh the routes to mesh network. 更新组网信息,若状态为删除态会直接物理删除.
remove(String sid, String did, {Context? ctx}) Future<void>
Remove the network route. 删除组网信息.
route(String mdc, {Context? ctx}) Future<Route?>
Route the network edge route. 获取当前节点到目标节点到组网信息.
routes({Context? ctx}) Future<List<Route>?>
Routes the network edge routes. 获取所有的组网信息.
toString() String
A string representation of this object.
inherited
version(String mdc, {Context? ctx}) Future<Versions?>
Version Network environment version. 获取对应节点的版本信息.

Operators

operator ==(Object other) bool
The equality operator.
inherited