Publisher class abstract

Implementers
Annotations
  • @SPI(name: "mpi")

Constructors

Publisher()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

broadcast(List<Event> events, {Context? ctx}) Future<List<String>?>
Broadcast the envent in queue. 广播事件到消息队列,会给所有数联网上的组网节点广播.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publish(List<Event> events, {Context? ctx}) Future<List<String>?>
Publish the envent in queue. 发布事件到消息队列.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited