Savepoint class abstract
- Implementers
- Annotations
-
- @SPI(name: "mpi")
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
begin(
DtxDefinition definition, {Context? ctx}) → Future< String?> - Begin a savepoint, this method will blocked a database transaction connection with timeout.
-
commit(
String xid, {Context? ctx}) → Future< void> - Commit a savepoint.
-
execute(
DtxBranch branch, {Context? ctx}) → Future< Uint8List?> - Execute a savepoint sql.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
redo(
Uint8List commit, {Context? ctx}) → Future< void> - Redo dolog void redo before commit.
-
rollback(
String xid, {Context? ctx}) → Future< void> - Rollback a savepoint.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited