Subscriber class abstract

Implementers
Annotations
  • @SPI(name: "mpi")

Constructors

Subscriber()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribe(Event event, {Context? ctx}) Future<void>
Subscribe the event with {@link tech.firmer.mesh.macro.Bindings} or {@link tech.firmer.mesh.macro.Binding}
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited