VM class abstract

Implementers
Annotations
  • @SPI(name: "mpi")

Constructors

VM()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compile(Script script, {Context? ctx}) Future<String?>
Compile the script. 编译脚本,编译通即会保存快照.
describe(String code, {Context? ctx}) Future<Script?>
Describe the script. 获取脚本详情.
exec(String code, Map<String, String> args, String dft, {Context? ctx}) Future<String?>
Exec the script with name. 执行脚本,此处为规则引擎服务化执行接口.
index(Paging idx, {Context? ctx}) Future<Page<Script>?>
Index the scripts. 分页检索脚本数据.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String code, {Context? ctx}) Future<void>
Remove the script. 删除脚本.
render(Script script, {Context? ctx}) Future<Map<String, Uint8List>?>
Render the script. 创建脚本脚手架.
setup(String code, String version, {Context? ctx}) Future<void>
Setup set up the script. 编译安装脚本到运行时中,为发布语意.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited