Mani class

Constructors

Mani({int? status, DateTime? createAt, DateTime? updateAt, String? createBy, String? updateBy})

Properties

createAt DateTime?
创建时间
getter/setter pair
createBy String?
创建人
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int?
状态
getter/setter pair
updateAt DateTime?
更新时间
getter/setter pair
updateBy String?
更新人
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited