CipherSuite class
Properties
-
csr
↔ Uint8List?
-
Cipher sign request
Cipher sign request
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
suite
↔ String?
-
Handshake suite
Handshake suite
getter/setter pair
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited