DalerCluster class
Constructors
-
DalerCluster({String? id, String? name, String? modal, Duration? keepalive, int? retries, int? rwmode, bool? failover, List<DalerInstance>? instances, int? status, String? url, String? proto, String? gfs})
-
Properties
-
failover
↔ bool?
-
Failover policy
Failover policy
getter/setter pair
-
gfs
↔ String?
-
全局函数
全局函数
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
↔ String?
-
Data Cluster ID
Data Cluster ID
getter/setter pair
-
instances
↔ List<DalerInstance>?
-
Instances
Instances
getter/setter pair
-
keepalive
↔ Duration?
-
Max keepalive duration
Max keepalive duration
getter/setter pair
-
modal
↔ String?
-
数据结构模态:graph/relation/kv/cache/object
数据结构模态:graph/relation/kv/cache/object
getter/setter pair
-
name
↔ String?
-
Data Cluster name
Data Cluster name
getter/setter pair
-
proto
↔ String?
-
Datasource protocol
Datasource protocol
getter/setter pair
-
retries
↔ int?
-
Max retry times
Max retry times
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
rwmode
↔ int?
-
ReadWrite mode
ReadWrite mode
getter/setter pair
-
status
↔ int?
-
状态
状态
getter/setter pair
-
url
↔ String?
-
Datasource URL
Datasource URL
getter/setter pair
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited