DalerDTSJob class
Constructors
-
DalerDTSJob({String? id, String? name, String? kind, String? modal, String? sid, String? did, String? sname, String? dname, String? abc, String? dag, String? raw, int? status, DateTime? createAt, DateTime? updateAt, String? createBy, String? updateBy})
-
Properties
-
abc
↔ String?
-
同步明细
同步明细
getter/setter pair
-
createAt
↔ DateTime?
-
创建时间
创建时间
getter/setter pair
-
createBy
↔ String?
-
创建人
创建人
getter/setter pair
-
dag
↔ String?
-
调度DAG
调度DAG
getter/setter pair
-
did
↔ String?
-
目标数据源ID
目标数据源ID
getter/setter pair
-
dname
↔ String?
-
目标数据源名称
目标数据源名称
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
↔ String?
-
ID
ID
getter/setter pair
-
kind
↔ String?
-
同步类型snapshot/cdc
同步类型snapshot/cdc
getter/setter pair
-
modal
↔ String?
-
数据结构模态:graph/relation/kv/cache/object/document/mq
数据结构模态:graph/relation/kv/cache/object/document/mq
getter/setter pair
-
name
↔ String?
-
名称
名称
getter/setter pair
-
raw
↔ String?
-
JSON信息
JSON信息
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
sid
↔ String?
-
源头数据源ID
源头数据源ID
getter/setter pair
-
sname
↔ String?
-
源头数据源名称
源头数据源名称
getter/setter pair
-
status
↔ int?
-
状态
状态
getter/setter pair
-
updateAt
↔ DateTime?
-
更新时间
更新时间
getter/setter pair
-
updateBy
↔ String?
-
更新人
更新人
getter/setter pair
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited