DalerInstance class

Inheritance

Constructors

DalerInstance({String? role, int? rw, int? ww, bool? failover})

Properties

failover bool?
Failover policy Failover policy
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Datasource ID Datasource ID
getter/setter pairinherited
memo String?
Datasource memo Datasource memo
getter/setter pairinherited
数据结构模态:graph/relation/kv/cache/object 数据结构模态:graph/relation/kv/cache/object
getter/setter pairinherited
name String?
Datasource name Datasource name
getter/setter pairinherited
proto String?
Datasource protocol Datasource protocol
getter/setter pairinherited
role String?
Is master or slave Is master or slave
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
rw int?
Read wight Read wight
getter/setter pair
status int?
状态 状态
getter/setter pairinherited
url String?
Datasource URL Datasource URL
getter/setter pairinherited
ww int?
Write wight Write wight
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited