DalerTest class

Constructors

DalerTest({String? id, String? expr, String? db})

Properties

db String?
Database name Database name
getter/setter pair
expr String?
Expression Expression
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
ID ID
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited