Settings class

Constructors

Settings({String? name, String? alias, String? icon, String? version, String? animate, String? slogan, String? memo, List<String>? metric, List<String>? tags, Map<String, List<String>>? auths, Map<String, String>? raw})

Properties

alias String?
别名 别名
getter/setter pair
animate String?
动画 动画
getter/setter pair
auths Map<String, List<String>>?
认证方式 认证方式
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
icon String?
图标 图标
getter/setter pair
memo String?
说明 说明
getter/setter pair
metric List<String>?
指标 指标
getter/setter pair
name String?
名称 名称
getter/setter pair
raw Map<String, String>?
扩展 扩展
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slogan String?
口号 口号
getter/setter pair
tags List<String>?
标签 标签
getter/setter pair
version String?
版本 版本
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited