StreamEntity class

Constructors

StreamEntity({String? role, String? party, String? kind, String? think, String? data, String? format, String? batch, String? step})

Properties

batch String?
Batch代表一次对话的所有响应 Batch代表一次对话的所有响应
getter/setter pair
data String?
getter/setter pair
format String?
Format mp3, mp4, wav, etc. Format mp3, mp4, wav, etc.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
kind String?
see ContentType see ContentType
getter/setter pair
party String?
体系 editor/converser 体系 editor/converser
getter/setter pair
role String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
step String?
Step表示步骤 Step表示步骤
getter/setter pair
think String?
AI思考过程 AI思考过程
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited