StreamHello class

Constructors

StreamHello({String? method, String? mode, String? traceId, String? token, String? conversationId, List<StreamEntity>? contents, StreamOption? options})

Properties

contents List<StreamEntity>?
getter/setter pair
conversationId String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
method String?
getter/setter pair
mode String?
getter/setter pair
options StreamOption?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String?
getter/setter pair
traceId String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited