StreamOption class

Constructors

StreamOption({String? searchType, bool? deepThink, bool? deepResearch, String? model, String? scene, String? operateType, String? language, String? knowledgeID, String? proxy, Map<String, String>? attaches, String? agent})

Properties

agent String?
agent交互的智能体 agent交互的智能体
getter/setter pair
attaches Map<String, String>?
补充参数 补充参数
getter/setter pair
deepResearch bool?
getter/setter pair
deepThink bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
knowledgeID String?
知识库编号 知识库编号
getter/setter pair
language String?
Language of the content, e.g., zh, en Language of the content, e.g., zh, en
getter/setter pair
model String?
Model name, e.g., Qwen2-Audio-7B-Instruct Model name, e.g., Qwen2-Audio-7B-Instruct
getter/setter pair
operateType String?
default as generate,rewrite default as generate,rewrite
getter/setter pair
proxy String?
代理地址 代理地址
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scene String?
Scene name, e.g., audio, video, text Scene name, e.g., audio, video, text
getter/setter pair
searchType String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited