CrtRevokeRequest class

Constructors

CrtRevokeRequest({String? id, int? reason})

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
主键ID 主键ID
getter/setter pair
reason int?
撤销原因 撤销原因
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited