KeyCsr class

Implementers

Constructors

KeyCsr({String? algo, String? domain, String? subject, int? length, DateTime? activeAt, DateTime? expireAt, String? mail, bool? isCA, String? caAlgo, String? caCert, String? caKey, List<String>? ips, String? name, int? usage})

Properties

activeAt DateTime?
激活时间,Unix毫秒时间 激活时间,Unix毫秒时间
getter/setter pair
algo String?
签发证书算法 签发证书算法
getter/setter pair
caAlgo String?
不是CA证书需要指定CA证书算法 不是CA证书需要指定CA证书算法
getter/setter pair
caCert String?
不是CA证书需要指定CA证书签名 不是CA证书需要指定CA证书签名
getter/setter pair
caKey String?
不是CA证书需要指定CA密钥签名 不是CA证书需要指定CA密钥签名
getter/setter pair
domain String?
证书域名 证书域名
getter/setter pair
expireAt DateTime?
失效时间,Unix毫秒时间 失效时间,Unix毫秒时间
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ips List<String>?
证书IP SANs 证书IP SANs
getter/setter pair
isCA bool?
是否CA证书 是否CA证书
getter/setter pair
length int?
证书密钥长度,根据算法而不同 证书密钥长度,根据算法而不同
getter/setter pair
mail String?
邮件联系信息 邮件联系信息
getter/setter pair
name String?
证书名称 证书名称
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subject String?
证书主题 证书主题
getter/setter pair
usage int?
证书用途 证书用途
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited