Keyset class

Constructors

Keyset({Map<String, Keys>? crts, Map<String, Keys>? roots})

Properties

crts Map<String, Keys>?
证书列表 证书列表
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
roots Map<String, Keys>?
根证书列表 根证书列表
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited