SecretKey class

Inheritance

Constructors

SecretKey({int? status, DateTime? createAt, DateTime? updateAt, String? createBy, String? updateBy})

Properties

algo String?
签发算法 签发算法
getter/setter pairinherited
createAt DateTime?
创建时间 创建时间
getter/setter pair
createBy String?
创建人 创建人
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
编号 编号
getter/setter pairinherited
length int?
密钥长度,根据算法而不同 密钥长度,根据算法而不同
getter/setter pairinherited
memo String?
说明 说明
getter/setter pairinherited
name String?
名称 名称
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int?
状态 状态
getter/setter pair
updateAt DateTime?
更新时间 更新时间
getter/setter pair
updateBy String?
更新人 更新人
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited