CommerceLicense class
Properties
-
cipher
↔ String?
-
License cipher
License cipher
getter/setter pair
-
createAt
↔ DateTime?
-
License create time
License create time
getter/setter pair
-
explain
↔ License?
-
License explain
License explain
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited