AccessCode class
Properties
-
code
↔ String?
-
OAuth authorize code
OAuth authorize code
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
redirectURI
↔ String?
-
OAuth authorize redirect uri
OAuth authorize redirect uri
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited