AccessGrant class

Constructors

AccessGrant({String? clientId, String? scope, String? state, int? flags})

Properties

clientId String?
OAuth client id OAuth client id
getter/setter pair
flags int?
OAuth authorize flags, 2 redirect, 4 callback OAuth authorize flags, 2 redirect, 4 callback
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String?
OAuth authorize scope OAuth authorize scope
getter/setter pair
state String?
OAuth authorize state OAuth authorize state
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited