Credential class

Constructors

Credential({String? clientId, String? authType, String? accessKey, String? secretKey, String? captcha})

Properties

accessKey String?
Auth authorize key like username Auth authorize key like username
getter/setter pair
authType String?
Auth type: password/verifycode/qrcode Auth type: password/verifycode/qrcode
getter/setter pair
captcha String?
Auth authorize captcha Auth authorize captcha
getter/setter pair
clientId String?
Auth client id Auth client id
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretKey String?
Auth authorize secret like password Auth authorize secret like password
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited