Inbound class
Properties
-
arguments
↔ List?
-
Invoke parameters
Invoke parameters
getter/setter pair
-
attachments
↔ Map<String, String>?
-
Invoke attachments
Invoke attachments
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited