Location class

Inheritance

Constructors

Location({String? ip, String? port, String? host, String? name})

Properties

hashCode int
The hash code for this object.
no setterinherited
host String?
host host
getter/setter pair
id String?
idc idc
getter/setter pairinherited
ip String?
ip ip
getter/setter pair
name String?
name name
getter/setter pair
port String?
port port
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited