Appdata class
Constructors
Properties
-
addrs
↔ List<
String> ? -
服务地址
服务地址
getter/setter pair
-
attachments
↔ Map<
String, String> ? -
扩展信息
扩展信息
getter/setter pair
-
应用Author
应用Author
getter/setter pair
- flags ↔ int?
-
标记
标记
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon ↔ String?
-
应用Icon
应用Icon
getter/setter pair
-
instanceIds
↔ List<
String> ? -
getter/setter pair
-
kinds
↔ List<
String> ? -
提供的服务类型
提供的服务类型
getter/setter pair
- lang ↔ String?
-
开发语言
开发语言
getter/setter pair
- memo ↔ String?
-
应用备注
应用备注
getter/setter pair
- name ↔ String?
-
应用名
应用名
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited