Registration<T> class

Constructors

Registration({String? instanceId, String? name, String? kind, String? address, T? content, int? timestamp, Map<String, String>? attachments})

Properties

address String?
地址 地址
getter/setter pair
attachments Map<String, String>?
补充信息 补充信息
getter/setter pair
content ↔ T?
注册内容明细 注册内容明细
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
instanceId String?
实例ID 实例ID
getter/setter pair
kind String?
类型 类型
getter/setter pair
name String?
名称 名称
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int?
注册时间 注册时间
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited