DynamicOption class

Constructors

DynamicOption({String? sap, String? crt, String? key, List<String>? cas, String? sni, bool? skip})

Properties

cas List<String>?
Route CA certificates Route CA certificates
getter/setter pair
crt String?
Route certificate Route certificate
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
key String?
Route private key Route private key
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sap String?
Signer algorithm provider. SM2 or others Signer algorithm provider. SM2 or others
getter/setter pair
skip bool?
Skip TLS verification Skip TLS verification
getter/setter pair
sni String?
Route service SNI Route service SNI
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited