DynamicRoute class
Constructors
-
DynamicRoute({String? name, String? matcher, int? priority, List<
String> ? services, List<String> ? filters, String? proxy, DynamicOption? option})
Properties
-
filters
↔ List<
String> ? -
Route filters
Route filters
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- matcher ↔ String?
-
Route matcher
Route matcher
getter/setter pair
- name ↔ String?
-
Route name
Route name
getter/setter pair
- option ↔ DynamicOption?
-
Route option
Route option
getter/setter pair
- priority ↔ int?
-
Route priority
Route priority
getter/setter pair
- proxy ↔ String?
-
Route proxy
Route proxy
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
services
↔ List<
String> ? -
Route backend
Route backend
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited