DynamicServer class

Constructors

DynamicServer({String? name, String? kind, String? listen, List<DynamicRoute>? routes, DynamicOption? option})

Properties

hashCode int
The hash code for this object.
no setterinherited
kind String?
Server kind, Reverse/Forward/TCPReverse/TCPForward Server kind, Reverse/Forward/TCPReverse/TCPForward
getter/setter pair
listen String?
Route listen address, e.g. Route listen address, e.g.
getter/setter pair
name String?
Route name Route name
getter/setter pair
option DynamicOption?
Route option Route option
getter/setter pair
routes List<DynamicRoute>?
Route rules Route rules
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited