FileMirror class

Constructors

FileMirror({String? name, String? pkg, String? path, Map<String, String>? imports, List<KindMirror>? kinds, List<VariableMirror>? variables, List<MethodMirror>? methods, Map<String, String>? set})

Properties

hashCode int
The hash code for this object.
no setterinherited
imports Map<String, String>?
getter/setter pair
kinds List<KindMirror>?
getter/setter pair
methods List<MethodMirror>?
getter/setter pair
name String?
getter/setter pair
path String?
getter/setter pair
pkg String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
set Map<String, String>?
getter/setter pair
variables List<VariableMirror>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited