KindMirror class

Constructors

KindMirror({String? name, Map<String, Map<String, String>>? macros, List<String>? comments, int? modifier, List<VariableMirror>? variables, List<MethodMirror>? methods, List<String>? supers, List<String>? traits, String? signature})

Properties

comments List<String>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
macros Map<String, Map<String, String>>?
getter/setter pair
methods List<MethodMirror>?
getter/setter pair
modifier int?
getter/setter pair
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String?
getter/setter pair
supers List<String>?
getter/setter pair
traits List<String>?
getter/setter pair
variables List<VariableMirror>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited