MethodMirror class
Constructors
-
MethodMirror({String? name, Map<
String, Map< ? macros, List<String, String> >String> ? comments, int? modifier, List<ParameterMirror> ? parameters, List<ReturnMirror> ? returns, List<ThrowableMirror> ? causes})
Properties
-
causes
↔ List<
ThrowableMirror> ? -
getter/setter pair
-
comments
↔ List<
String> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
macros
↔ Map<
String, Map< ?String, String> > -
getter/setter pair
- modifier ↔ int?
-
getter/setter pair
- name ↔ String?
-
getter/setter pair
-
parameters
↔ List<
ParameterMirror> ? -
getter/setter pair
-
returns
↔ List<
ReturnMirror> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited