ParameterMirror class

Constructors

ParameterMirror({String? name, Map<String, Map<String, String>>? macros, List<String>? comments, String? kind, String? value, int? flags, String? usage})

Properties

comments List<String>?
getter/setter pair
flags int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
kind String?
getter/setter pair
macros Map<String, Map<String, String>>?
getter/setter pair
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usage String?
getter/setter pair
value String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited