Packet class

Inheritance

Constructors

Packet({String? bucket, String? src, String? rid, String? dst, String? sni, String? addr})

Properties

addr String?
packet addr Packet net address Packet net address
getter/setter pair
body Uint8List?
packet body Packet body Packet body
getter/setter pairinherited
bucket String?
one by one with connection Packet bucket Packet bucket
getter/setter pair
dst String?
packet dst instId Packet destination Packet destination
getter/setter pair
flag int?
package flag Packet flag in TCPHeader Packet flag in TCPHeader
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
index int?
packet index Packet idx Packet idx
getter/setter pairinherited
rid String?
packet ref instId Packet reference Packet reference
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sni String?
packet tls sni Packet SNI Packet SNI
getter/setter pair
src String?
packet src instId Packet source Packet source
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited