Payload class
Properties
-
body
↔ Uint8List?
-
packet body
Packet body
Packet body
getter/setter pair
-
flag
↔ int?
-
package flag
Packet flag in TCPHeader
Packet flag in TCPHeader
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
index
↔ int?
-
packet index
Packet idx
Packet idx
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited