WorkChart class
Properties
-
cno
↔ String?
-
Workflow chart code
Workflow chart code
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
maintainer
↔ Worker?
-
Workflow maintainer
Workflow maintainer
getter/setter pair
-
name
↔ String?
-
Workflow name
Workflow name
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
sides
↔ List<WorkSide>?
-
Workflow sides
Workflow sides
getter/setter pair
-
status
↔ int?
-
Workflow status
Workflow status
getter/setter pair
-
vertices
↔ List<WorkVertex>?
-
Workflow vertices
Workflow vertices
getter/setter pair
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited