WorkIntent class
Properties
-
applier
↔ Worker?
-
Workflow applier
Workflow applier
getter/setter pair
-
bno
↔ String?
-
Business code
Business code
getter/setter pair
-
cno
↔ String?
-
Workflow chart code
Workflow chart code
getter/setter pair
-
context
↔ Map<String, String>?
-
Workflow context
Workflow context
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited