WorkRoutine class
Properties
-
bno
↔ String?
-
Business code
Business code
getter/setter pair
-
chart
↔ WorkChart?
-
Workflow chart
Workflow chart
getter/setter pair
-
context
↔ Map<String, String>?
-
Workflow context
Workflow context
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
rno
↔ String?
-
Workflow routine code
Workflow routine code
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
status
↔ int?
-
Workflow status
Workflow status
getter/setter pair
-
tasks
↔ List<WorkTask>?
-
Workflow tasks
Workflow tasks
getter/setter pair
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited