WorkTask class
Properties
-
context
↔ Map<String, String>?
-
Workflow context
Workflow context
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
reviewers
↔ List<Worker>?
-
Workflow vertex reviewers
Workflow vertex reviewers
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
status
↔ int?
-
Workflow vertex status
Workflow vertex status
getter/setter pair
-
vertex
↔ WorkVertex?
-
Workflow vertex
Workflow vertex
getter/setter pair
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited