MultiFactorAuthConfig class

Constructors

MultiFactorAuthConfig({String? appset, AuthMode initialPanelMode = AuthMode.account, AccountProvider initialAccountMode = AccountProvider.password})
const

Properties

appset String?
final
hashCode int
The hash code for this object.
no setteroverride
initialAccountMode AccountProvider
final
initialPanelMode AuthMode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override