MultiFactorLoginNotifier class

Properties

hashCode int
The hash code for this object.
no setterinherited
ref → Ref
The Ref associated with this notifier.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state MultiFactorAuthState
The value currently exposed by this notifier.
getter/setter pairinherited
stateOrNull MultiFactorAuthState?
The value currently exposed by this Notifier.
no setterinherited

Methods

build() MultiFactorAuthState
Initialize a Notifier.
changeAccountProvider(AccountProvider value) → void
changeAgreement(bool value) → void
changeAuthMode(AuthMode mode) → void
changeCode(String value) → void
changePassword(String value) → void
changeScanProvider(ScanProvider value) → void
changeUsername(String value) → void
codeSubmission() CodeLoginSubmission
completeSubmitSlide() → void
listenSelf(void listener(MultiFactorAuthState? previous, MultiFactorAuthState next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener
Listens to changes on the value exposed by this provider.
inherited
load() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
passwordSubmission() PasswordLoginSubmission
resetSubmitSlide() → void
runBuild() → WhenComplete?
Executes Notifier.build.
inherited
setChallengeLoading(bool value) → void
setChallengeToken(String? value) → void
setSubmitting(bool value) → void
startSubmitSlide() → void
toggleAgreement() → void
togglePasswordVisibility() → void
toString() String
A string representation of this object.
inherited
updateShouldNotify(MultiFactorAuthState previous, MultiFactorAuthState next) bool
A method invoked when the state exposed by this Notifier changes. It compares the previous and new value, and return whether listeners should be notified.
inherited
updateSubmitSlide(double value) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited