CodeLoginSubmission class

Constructors

CodeLoginSubmission({required String username, required String code, required bool agreed, String? challengeToken})
const

Properties

agreed bool
final
challengeToken String?
final
code String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited