MeshErrorReporter class

Properties

hashCode int
The hash code for this object.
no setterinherited
notices Stream<MeshErrorNotice>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

capture<T>(Future<T> action(), {required String category, bool fatal = false, String? message, Map<String, String>? metadata, FutureOr<void> onError(Object error, StackTrace stackTrace)?, FutureOr<void> onFinally()?, bool rethrowError = false}) Future<T?>
configure({bool remoteReportingEnabled = kReleaseMode, MeshErrorMessageResolver? messageResolver}) → void
guard<T>(Future<T> action(), {String category = 'app.zone', bool fatal = true}) Future<T>
installFlutterErrorHandlers({bool remoteReportingEnabled = kReleaseMode, MeshErrorMessageResolver? messageResolver}) → void
log(String message, {String category = 'app.log', Map<String, String>? metadata}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
report(Object error, StackTrace stackTrace, {String category = 'app.error', bool fatal = false, String? message, Map<String, String>? metadata, bool present = false, MeshErrorSeverity severity = MeshErrorSeverity.error}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance MeshErrorReporter
final