AuthSessionSnapshot class

Constructors

AuthSessionSnapshot({required String token, required Session? session, required DateTime? expiresAt})
const

Properties

expiresAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
isExpired bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session Session?
final
token String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited