AuthState class

Constructors

AuthState({required bool ready, required Session? session, required DateTime? expiresAt, required bool authenticating})
const
AuthState.initial()
const

Properties

authenticating bool
final
expiresAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
ready bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session Session?
final

Methods

copyWith({bool? ready, Object? session = _authSentinel, Object? expiresAt = _authSentinel, bool? authenticating}) AuthState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited