StreamContext class

Constructors

StreamContext({Client? client, Uri? endpoint})

Properties

endpoint Uri?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
fileup(Uint8List file, {String? filename, String? bucket, String? ext, StreamUploadProgress? onprogress, Uri? endpoint}) Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited