MPICipherProvider class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decode(CipherEntity cipher, {Context? ctx})
→ Future<Uint8List?>
-
Decode the data object, actual dencrypt or deanonymize.
数据解码,实际根据不同的密态场景底层可能是解密或去匿名化.
override
-
encode(CipherEntity explain, {Context? ctx})
→ Future<Uint8List?>
-
Encode the data object, actual encrypt or anonymize.
数据编码,实际根据不同的密态场景底层可能是加密或匿名化.
override
-
ioc()
→ void
-
override
-
keygen(CipherKeygen keygen, {Context? ctx})
→ Future<CipherKey?>
-
Keygen generate first phase keys.
协商签发第一阶段密钥,各方只提供自己的公钥或公钥片段.
override
-
methods()
→ Map<String, Introspector>
-
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
recode(CipherTxEntity cipher, {Context? ctx})
→ Future<Uint8List?>
-
Recode the data object, actual rencrypt or reanonymize.
数据重编码,实际根据不同的密态场景底层可能是重加密或重匿名.
override
-
regen(CipherRegen keygen, {Context? ctx})
→ Future<CipherKey?>
-
Regen generate second phase keys.
协商签发第二阶段密钥,各方只提供自己的公钥或公钥片段.
override
-
suite(CipherHello hello, {Context? ctx})
→ Future<CipherSuite?>
-
Suite cipher suite in local party.
产生本方密钥协商套件.
override
-
toString()
→ String
-
A string representation of this object.
inherited