MPINetwork class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
accessible(Route route, {Context? ctx})
→ Future<bool?>
-
Accessible Check the mesh network is accessible.
override
-
disable(String mdc, {Context? ctx})
→ Future<void>
-
Disable the network
override
-
enable(String mdc, {Context? ctx})
→ Future<void>
-
Enable the network
override
-
environ({Context? ctx})
→ Future<Environ?>
-
Environ Get the meth network environment fixed information.
override
-
exports(String mdc, {Context? ctx})
→ Future<String?>
-
Exports the weave certificate.
override
-
imports(String crt, {Context? ctx})
→ Future<void>
-
Imports the weave certificate.
override
-
index(Paging index, {Context? ctx})
→ Future<Page<Route>?>
-
Index the network edges
override
-
ioc()
→ void
-
override
-
methods()
→ Map<String, Introspector>
-
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
refresh(List<Route> routes, {Context? ctx})
→ Future<void>
-
Refresh the routes to mesh network.
override
-
route(String mdc, {Context? ctx})
→ Future<Route?>
-
Route the network edge route.
override
-
routes({Context? ctx})
→ Future<List<Route>?>
-
Routes the network edge routes.
override
-
toString()
→ String
-
A string representation of this object.
inherited
-
version(String mdc, {Context? ctx})
→ Future<Versions?>
-
Version
Network environment version.
override