MPIRegistry class
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
export(
String kind, {Context? ctx}) → Future< List< Registration> ?> -
Export
override
-
ioc(
) → void -
override
-
methods(
) → Map< String, Introspector> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
Registration registration, {Context? ctx}) → Future< void> -
Register
override
-
registers(
List< Registration> registrations, {Context? ctx}) → Future<void> -
Registers
override
-
toString(
) → String -
A string representation of this object.
inherited
-
unregister(
Registration registration, {Context? ctx}) → Future< void> -
Unregister
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited