HTTPConsumer class
- Implemented types
- Implementers
- Annotations
-
- @SPI(name: 'http')
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hc → Client
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< void> -
Closer is release hook
override
-
consume(
Context ctx, String urn, Execution exec, Uint8List inbound) → Future< Uint8List> -
Consume the input payload.
urn Actual uniform resource Domain Name.
execution Service reference.
inbound Input arguments.
Output payload
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → Future< void> -
Start the mesh broker.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited