Builtin class abstract
- Implementers
- Annotations
-
- @SPI(name: "mpi")
Constructors
- Builtin()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
debug(
Map< String, String> features, {Context? ctx}) → Future<void> - Debug set the application debug features like log.level=126. 设置应用调试信息,如日志级别log.level.
-
doc(
String name, String formatter, {Context? ctx}) → Future< String?> - Doc export the documents. 按格式导出文档.
-
dump(
List< String> names, {Context? ctx}) → Future<Map< String, String> ?> - Dump the application data. 导出应用相关数据用于分析应用运行情况.
-
fallback(
{Context? ctx}) → Future< void> - Fallback is fallback service. GRPC降级服务能力,用于一些状态的降级,用于返回给客户端结构化数据结果.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sse(
StreamHello hello, {Context? ctx}) → Stream< StreamEntity?> - SSE stream server. 服务端流式响应
-
stats(
List< String> features, {Context? ctx}) → Future<Map< String, String> ?> - Stats collect health check stats. 收集应用状态信息并输出.
-
toString(
) → String -
A string representation of this object.
inherited
-
version(
{Context? ctx}) → Future< Versions?> - Version get the builtin application version. 内置的应用版本信息.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited