Builtin class abstract

Implementers
Annotations
  • @SPI(name: "mpi")

Constructors

Builtin()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(Map<String, String> features, {Context? ctx}) Future<void>
Debug set the application log level.
doc(String name, String formatter, {Context? ctx}) Future<String?>
Doc export the documents.
dump(List<String> names, {Context? ctx}) Future<Map<String, String>?>
Dump the application data.
fallback({Context? ctx}) Future<void>
Fallback is fallback service
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stats(List<String> features, {Context? ctx}) Future<Map<String, String>?>
Stats will collect health check stats.
toString() String
A string representation of this object.
inherited
version({Context? ctx}) Future<Versions?>
Version will get the builtin application version.

Operators

operator ==(Object other) bool
The equality operator.
inherited