Commercialize class abstract
- Implementers
- Annotations
-
- @SPI(name: "mpi")
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dump(
String nodeId, {Context? ctx}) → Future< List< CommerceEnviron> ?> - Dump the node identity.
-
history(
String instId, {Context? ctx}) → Future< List< CommerceLicense> ?> - History list the sign license in history, the latest is the first index.
-
issued(
String name, String kind, String cname, {Context? ctx}) → Future< CommerceEnviron?> - Issued mesh node identity.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sign(
License lsr, {Context? ctx}) → Future< CommerceLicense?> - Sign license, only glab has permission to sign.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited