Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decrypt(Uint8List buf, Map<String, Uint8List> keys, {Context? ctx})
→ Future<Uint8List?>
-
Decrypt binary to decrypted binary.
-
encrypt(Uint8List buf, Map<String, Uint8List> keys, {Context? ctx})
→ Future<Uint8List?>
-
Encrypt binary to encrypted binary.
-
hash(Uint8List buf, Map<String, Uint8List> keys, {Context? ctx})
→ Future<Uint8List?>
-
Hash compute the hash value.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
sign(Uint8List buf, Map<String, Uint8List> keys, {Context? ctx})
→ Future<Uint8List?>
-
Sign compute the signature value.
-
toString()
→ String
-
A string representation of this object.
inherited
-
verify(Uint8List buf, Map<String, Uint8List> keys, {Context? ctx})
→ Future<bool?>
-
Verify the signature value.