DataHouse class abstract
- Implementers
- Annotations
-
- @SPI(name: "mpi")
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
indies(
Paging idx, {Context? ctx}) → Future< Page?> - Indies bigdata manifest index. 读取大数据索引明细.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
Paging idx, {Context? ctx}) → Future< Page?> - Read bigdata from data house. 大数据批量读.
-
tables(
Paging idx, {Context? ctx}) → Future< Page?> - Tables bigdata tables. 读取大数据存储表信息.
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
Document doc, {Context? ctx}) → Future< void> - Write bigdata to data house. 大数据单文档写入.
-
writes(
List< Document> docs, {Context? ctx}) → Future<void> - Writes bigdata to data house. 大数据批量写入.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited