Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
invoke(String urn, Map<String, dynamic> param, {Context? ctx})
→ Future
-
Invoke with fewer returns
In multi returns, it will discard multi returns
-
invoke0(String urn, dynamic param, {Context? ctx})
→ Future
-
Invoke0 with fewer returns in generic mode
In multi returns, it will discard multi returns
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited