Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
append(Keys car, {Context? ctx})
→ Future<void>
-
Append the keys.
上传证书.
-
describe(String id, {Context? ctx})
→ Future<Keys?>
-
Describe will return the keys by code.
检索KMS中存储的证书详情.
-
describeSecret(String id, {Context? ctx})
→ Future<SecretKey?>
-
DescribeSecret the crypt keys.
删除密钥.
-
environ({Context? ctx})
→ Future<Environ?>
-
Environ will return the keystore environ.
获取MESH网络中当前节点的环境信息.
-
explain(String algo, String keys, {Context? ctx})
→ Future<String?>
-
Explain the keys.
证书解释.
-
generateSecret(SecretCsr csr, {Context? ctx})
→ Future<String?>
-
GenerateSecret the crypt keys.
生成密钥.
-
index(Paging idx, {Context? ctx})
→ Future<Page<Keys>?>
-
Index will return the keystore environ.
分页检索KMS中存储的所有证书列表.
-
indexSecret(Paging idx, {Context? ctx})
→ Future<Page<SecretKey>?>
-
IndexSecret the crypt keys.
分页检索密钥列表.
-
issue(KeyCsr csr, {Context? ctx})
→ Future<Keys?>
-
Issue will apply the certification.
签发证书,签发根证书和通信证书均使用该接口.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(String id, {Context? ctx})
→ Future<void>
-
Remove the keys.
证书删除.
-
removeSecret(String id, {Context? ctx})
→ Future<void>
-
RemoveSecret the crypt keys.
删除密钥.
-
reset(Environ env, {Context? ctx})
→ Future<void>
-
Reset will override the keystore environ.
重置MESH网络中当前节点的环境信息.
-
revoke(CrtRevokeRequest crr, {Context? ctx})
→ Future<void>
-
Revoke will revoke the keys.
撤销证书.
-
rotate(CrtRotateRequest crr, {Context? ctx})
→ Future<void>
-
Rotate will rotate the keys.
证书轮换.
-
toString()
→ String
-
A string representation of this object.
inherited