KMS class abstract

Implementers
Annotations
  • @SPI(name: "mpi")

Constructors

KMS()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

environ({Context? ctx}) Future<Environ?>
Environ will return the keystore environ.
issue(KeyCsr csr, {Context? ctx}) Future<List<Keys>?>
Issue will apply the certification.
list(String cno, {Context? ctx}) Future<List<Keys>?>
List will return the keystore environ.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset(Environ env, {Context? ctx}) Future<void>
Reset will override the keystore environ.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited