Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
accept(String code, {Context? ctx})
→ Future<AccessCode?>
-
Accept OAuth2 accept grant code.
-
apply(String factor, Duration duration, {Context? ctx})
→ Future<String?>
-
Apply trust authenticate token.
申请信任登录令牌.
-
authenticate(String token, {Context? ctx})
→ Future<Session?>
-
Authenticate OAuth2 authenticate.
-
authorize(String code, {Context? ctx})
→ Future<AccessToken?>
-
Authorize OAuth2 code authorize.
-
captcha(String kind, Map<String, String> features, {Context? ctx})
→ Future<Captcha?>
-
Captcha apply a graphics captcha.
获取验证码.
-
destroy(String token, {Context? ctx})
→ Future<void>
-
Destroy OAuth2 auth token destroy.
-
grant(AccessGrant grant, {Context? ctx})
→ Future<GrantCode?>
-
Grant OAuth2 code authorize.
-
matches(String mno, String value, {Context? ctx})
→ Future<bool?>
-
Matches a graphics captcha value.
验证码校验.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
quickauth(Credential credential, {Context? ctx})
→ Future<AccessToken?>
-
Quickauth OAuth2 quick authorize, contains grant code and code authorize.
快速授权,OAuth2多阶段合并为一阶段.
-
refresh(String token, {Context? ctx})
→ Future<AccessToken?>
-
Refresh OAuth2 auth token refresh.
-
reject(String code, {Context? ctx})
→ Future<void>
-
Reject OAuth2 reject grant code.
-
toString()
→ String
-
A string representation of this object.
inherited
-
verify(String token, {Context? ctx})
→ Future<AccessToken?>
-
Verify the trust token.
验证信任登录令牌.