Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attach(String uri, String pdc, {Context? ctx})
→ Future<String?>
-
Attach the tcp over transport with uri and partner mdc.
-
clean(List<String> buckets, {Context? ctx})
→ Future<void>
-
Clean all packets in buckets.
-
detach(String descriptor, {Context? ctx})
→ Future<void>
-
Detach the tcp over transport with descriptor.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
read(String bucket, int limit, {Context? ctx})
→ Future<List<Packet>?>
-
Read packets in bucket.
-
scan(String rid, int h, int limit, {Context? ctx})
→ Future<List<Packet>?>
-
Scan packets with ref and header in all buckets.
-
toString()
→ String
-
A string representation of this object.
inherited
-
write(Packet packet, {Context? ctx})
→ Future<void>
-
Write packet to bucket.