DalerBinlog class

Constructors

DalerBinlog({String? id, String? name, String? modal, String? path, int? size, int? lines, DateTime? createAt})

Properties

createAt DateTime?
Binlog create time Binlog create time
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Binlog ID Binlog ID
getter/setter pair
lines int?
Binlog lines Binlog lines
getter/setter pair
数据结构模态:graph/relation/kv/cache/object 数据结构模态:graph/relation/kv/cache/object
getter/setter pair
name String?
Binlog name Binlog name
getter/setter pair
path String?
Binlog path Binlog path
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
Binlog size in bytes Binlog size in bytes
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited