DalerSource class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
↔ String?
-
Datasource ID
Datasource ID
getter/setter pair
-
memo
↔ String?
-
Datasource memo
Datasource memo
getter/setter pair
-
modal
↔ String?
-
数据结构模态:graph/relation/kv/cache/object
数据结构模态:graph/relation/kv/cache/object
getter/setter pair
-
name
↔ String?
-
Datasource name
Datasource name
getter/setter pair
-
proto
↔ String?
-
Datasource protocol
Datasource protocol
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
status
↔ int?
-
状态
状态
getter/setter pair
-
url
↔ String?
-
Datasource URL
Datasource URL
getter/setter pair
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited