CrtRotateRequest class
Properties
-
algo
↔ String?
-
算法
算法
getter/setter pair
-
expireAt
↔ DateTime?
-
证书过期时间
证书过期时间
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
↔ String?
-
主键ID
主键ID
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited