SecretCsr class
Properties
-
algo
↔ String?
-
签发算法
签发算法
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
↔ String?
-
编号
编号
getter/setter pair
-
length
↔ int?
-
密钥长度,根据算法而不同
密钥长度,根据算法而不同
getter/setter pair
-
memo
↔ String?
-
说明
说明
getter/setter pair
-
name
↔ String?
-
名称
名称
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited