Registration<T> class

Constructors

Registration({String? instanceId, String? name, String? kind, String? address, T? content, int? timestamp, Map<String, String>? attachments})

Properties

address String?
getter/setter pair
attachments Map<String, String>?
getter/setter pair
content ↔ T?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
instanceId String?
getter/setter pair
kind String?
getter/setter pair
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited