AuthContext class

Inheritance

Constructors

AuthContext.global()
factory

Properties

expiresAt DateTime?
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
session Session?
no setter
state AuthState
no setter
token String
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
apply(AuthMode mode, {String? factor, Duration? duration, Context? ctx}) Future<String>
attach(Context? ctx, {String? token}) Context
authenticate({Context? ctx, bool forceRefresh = false}) Future<Session>
authorize(AuthMode mode, Credential account, {Context? ctx}) Future<Session>
authorized() bool
destroy({Context? ctx, bool localOnly = false}) Future<void>
dispose() → void
Discards any resources used by the object.
inherited
headers() Map<String, String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
ready() Future<void>
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited
verify(String token, {Context? ctx}) Future<Session>

Operators

operator ==(Object other) bool
The equality operator.
inherited